#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: admin.py 11977 2020-03-16 18:37:48Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2020-03-17 03:37:48 +0900 (週二, 17 三月 2020) $
# $Revision: 11977 $

from django.contrib import admin
from solo.admin import SingletonModelAdmin

from Zephyrus.facebook.models import FacebookFan, FacebookPhoto, FacebookSettings

class FacebookFanAdmin(admin.ModelAdmin):
    list_display = (
        'url', 'limit',
    )
    
class FacebookPhotoAdmin(admin.ModelAdmin):
    list_display = (
        'url', 'limit',
    )


admin.site.register(FacebookFan, FacebookFanAdmin)
admin.site.register(FacebookPhoto, FacebookPhotoAdmin)
admin.site.register(FacebookSettings, SingletonModelAdmin)